@@ -1,6 +1,6 @@
 package Tapper::Installer::Precondition::Exec;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Installer::Precondition::Exec::VERSION = '5.0.0';
+$Tapper::Installer::Precondition::Exec::VERSION = '5.0.1';
 use 5.010;
 use strict;
 use warnings;
@@ -8,7 +8,6 @@ use warnings;
 use Moose;
 use IO::Handle; # needed to set pipe nonblocking
 use IO::Select;
-use Linux::Personality qw/personality PER_LINUX32 /;
 
 extends 'Tapper::Installer::Precondition';
 
@@ -66,7 +65,9 @@ sub install
                 ($error, $output)    = $self->log_and_exec("mount -t sysfs sys ".$self->cfg->{paths}{base_dir}."/sys");
                 ($error, $output)    = $self->log_and_exec("mount -t proc proc ".$self->cfg->{paths}{base_dir}."/proc");
                 my $arch = $exec->{arch} // "";
-                personality(PER_LINUX32) if $arch eq 'linux32';
+		if ($arch eq 'linux32') {
+			Linux::Personality::personality(Linux::Personality::PER_LINUX32());
+		}
                 chroot $self->cfg->{paths}{base_dir};
                 chdir ("/");
                 %ENV = (%ENV, %{$exec->{environment} || {} });
@@ -155,7 +156,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2022 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
